<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Chỉnh sửa mẫu người nhận");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Chỉnh sửa mẫu người nhận");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Mẫu trang");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Bạn có thể cài đặt nhiều hơn một người nhận bằng cách tách các email bằng dấu phẩy.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Tiết kiệm nhận ...");
define('VIEW_FORM_TABLES_HEADING', "Xem bảng biểu mẫu");
define('VIEW_FORM_TABLES_BTN', "Xem bảng biểu mẫu");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Chọn một bảng để xem");
define('VIEW_FORM_TABLES_FILTER_READ', "Lọc tin nhắn đã đọc");
?>